---
title: "Another Page"
description: Just another example page
kind: page
id: page2
author: Russ Olsen
layout:  page.haml
---

This is a second example page in the QRN site.

[Back to the home page](/index.html)
